==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaWrp.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class RealizacjaWrp extends GenericDPSObject {
    /**
     * REALIZACJA_WRP.OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long operacjaId;

    /**
     * REALIZACJA_WRP.PORA_DNIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poraDniaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_WRP.OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_WRP.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @return REALIZACJA_WRP.PORA_DNIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoraDniaId() {
        return poraDniaId;
    }

    /**
     * REALIZACJA_WRP.PORA_DNIA_ID
     *
     * @param poraDniaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoraDniaId(Long poraDniaId) {
        this.poraDniaId = poraDniaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaWrp other = (RealizacjaWrp) that;
        return (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()))
            && (this.getPoraDniaId() == null ? other.getPoraDniaId() == null : this.getPoraDniaId().equals(other.getPoraDniaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        result = prime * result + ((getPoraDniaId() == null) ? 0 : getPoraDniaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", operacjaId=").append(operacjaId);
        sb.append(", poraDniaId=").append(poraDniaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaWrp.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class RealizacjaWrp extends GenericDPSObject {
    /**
     * REALIZACJA_WRP.OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long operacjaId;

    /**
     * REALIZACJA_WRP.PORA_DNIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poraDniaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_WRP.OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_WRP.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @return REALIZACJA_WRP.PORA_DNIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoraDniaId() {
        return poraDniaId;
    }

    /**
     * REALIZACJA_WRP.PORA_DNIA_ID
     *
     * @param poraDniaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoraDniaId(Long poraDniaId) {
        this.poraDniaId = poraDniaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaWrp other = (RealizacjaWrp) that;
        return (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()))
            && (this.getPoraDniaId() == null ? other.getPoraDniaId() == null : this.getPoraDniaId().equals(other.getPoraDniaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        result = prime * result + ((getPoraDniaId() == null) ? 0 : getPoraDniaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", operacjaId=").append(operacjaId);
        sb.append(", poraDniaId=").append(poraDniaId);
        sb.append("]");
        return sb.toString();
    }
}
